@@ -3,8 +3,13 @@
 void Alternatives::glob(string dir, GlobContext &context)
 try
 {
-    for_each(d_command.begin(), d_command.end(),    // add */ to each cmd arg
-                        FnWrap::unary(addPath, dir));
+    for_each(
+        d_command.begin(), d_command.end(),    // add */ to each cmd arg
+        [&](std::string const &element)
+        {
+            (dir += element) += "*/";
+        }
+    );
 
     dir.resize(dir.length() - 1);                   // remove trailing /
 
@@ -12,8 +17,19 @@ try
 
     Glob glob(dir, Glob::NOSORT, Glob::DEFAULT);    // find matching elements
 
-    for_each(glob.begin(), glob.end(),              // accept unique dirs.
-                         FnWrap::unary(globFilter, context));
+    for_each(
+        glob.begin(), glob.end(),              // accept unique dirs.
+        [&](char const *entry)
+        {
+            globFilter(entry, context);
+        }
+    );
 }
 catch (Errno const &err)      // to catch the exception from glob
 {}
+
+
+
+
+
+
